@@ -1,5 +1,5 @@
 /***************************************************************************
-*   KBlocks, a falling blocks game for KDE                                *
+*   KBlocks, a falling blocks game by KDE                                *
 *   Copyright (C) 2010 Zhongjie Cai <squall.leonhart.cai@gmail.com>       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -11,7 +11,6 @@
 #define KBLOCKSSINGLEPLAYER_H
 
 #include <QTimer>
-#include <QList>
 
 #include "SingleGameInterface.h"
 #include "GamePlayerInterface.h"
@@ -44,8 +43,8 @@ private slots:
     void doAction();
 
 private:
-    GamePlayerInterface *mpPlayer;
-    SingleGameInterface *mpGame;
+    GamePlayerInterface *mpPlayer = nullptr;
+    SingleGameInterface *mpGame = nullptr;
 
     int mPlayerState;
 
